import ApexCharts from 'apexcharts';
import React, { Component } from 'react';

export default class Charts extends Component {
  constructor(props) {
    super(props);
    this.chartRef = React.createRef();
    this.state = {
      chart: null
    }
  }

  render() {
    return (
      React.createElement("div", {ref: this.chartRef})
    );
  }

  componentDidMount() {
    const newOptions = {
      chart: {
        type: this.props.type ? this.props.type : 'line',
        height: this.props.height ? this.props.height : 'auto',
        width: this.props.width ? this.props.width : '100%'
      },
      series: this.props.series
    }

    const config = ApexCharts.merge(this.props.options, newOptions);
    const chart = new ApexCharts(this.chartRef.current, config)
    chart.render().then(() => {
      this.setState({
        chart
      })
    })
  }

  //Used to check the values being passed in to avoid unnecessary changes.
  shouldComponentUpdate(nextProps) {
    //Lazy object comparison
    return !(JSON.stringify(nextProps.options) === JSON.stringify(this.props.options) && JSON.stringify(nextProps.series) === JSON.stringify(this.props.series));
  }

  componentWillUpdate(nextProps) {
    const newOptions = {
      chart: {
        type: nextProps.type ? nextProps.type : 'line',
        width: nextProps.width ? nextProps.width : '100%',
        height: nextProps.height ? nextProps.height : 'auto'
      },
      series: nextProps.series
    }

    const config = ApexCharts.merge(nextProps.options, newOptions);

    // series is not changed,but options are changed
    if (JSON.stringify(nextProps.series) === JSON.stringify(this.props.series)) {
      this.state.chart.updateOptions(config)
    }
    // options are not changed, just the series is changed
    else if (JSON.stringify(nextProps.options) === JSON.stringify(this.props.options)) {
      this.state.chart.updateSeries(nextProps.series)

    // both maybe changed
    } else {
      this.state.chart.updateOptions(config)
    }
  }

  componentWillUnmount() {
    this.state.chart.exec(this.props.options.chart.id, 'destroy');
  }
}